# E019: invalid binding in let statement

`const`, `let`, and `var` can only declare variables directly or by
destructuring an array or an object. Number literals and keywords are not
allowed where a variable name is expected:

```javascript-ignoring-extra-errors
let wordCounts = {for: 4, if: 5, while: 0};
let {for, if} = wordCounts;

let queue = ["first", "second", "third"];
let {first: 0} = queue;
```

To fix this error when destructuring an object with keyword keys, pick a
variable name which is not a keyword:

    let wordCounts = {for: 4, if: 5, while: 0};
    let {for: forWordCount, if: ifWordCount} = wordCounts;

When destructuring an object, it's common to confuse the variable name with the
key. Make sure the variable name comes after the `:`:

    let queue = ["first", "second", "third"];
    let {0: first} = queue;
